@@ -21,14 +21,14 @@ package Text::CSV_XS;
 require 5.004;
 use strict;
 
-require DynaLoader;
-require Exporter;
 
-use vars qw($VERSION @ISA @EXPORT_OK);
+use DynaLoader ();
+
+use vars qw($VERSION @ISA);
+
+$VERSION =     '0.16';
+@ISA =         qw(DynaLoader);
 
-$VERSION =     '0.14';
-@ISA =         qw(Exporter DynaLoader);
-@EXPORT_OK = qw(IV PV NV);
 
 sub PV () { 0 }
 sub IV () { 1 }
@@ -164,7 +164,6 @@ sub combine ($@) {
   my($ref) = \$str;
   $self->{'_FIELDS'} = \@part;
   $self->{'_ERROR_INPUT'} = undef;
-  $self->{'_STATUS'} = 0;
   $self->{'_STATUS'} =
       (@part > 0)  &&  $self->Encode(\$str, \@part, 0, $self->{'eol'});
   $self->{'_STRING'} = $str;
@@ -219,13 +218,13 @@ sub parse ($$) {
 #
 ############################################################################
 
-sub print ($$$) {
-    my($self, $io, $fields) = @_;
-    $self->{'_ERROR_INPUT'} = undef;
-    $self->{'_STRING'} = undef;
-    $self->{'_FIELDS'} = $fields;
-    $self->{'_STATUS'} = $self->Encode($io, $fields, 1, $self->{'eol'});
-}
+# sub print ($$$) {
+#     my($self, $io, $fields) = @_;
+#     $self->{'_ERROR_INPUT'} = undef;
+#     $self->{'_STRING'} = undef;
+#     $self->{'_FIELDS'} = $fields;
+#     $self->{'_STATUS'} = $self->Encode($io, $fields, 1, $self->{'eol'});
+# }
 
 
 ############################################################################
@@ -249,17 +248,17 @@ sub print ($$$) {
 #
 ############################################################################
 
-sub getline ($$) {
-    my($self, $io) = @_;
-    my($fields) = [];
-    $self->{'_ERROR_INPUT'} = undef;
-    $self->{'_STRING'} = undef;
-    $self->{'_FIELDS'} = $fields;
-    if ($self->{'_STATUS'} = $self->Decode($io, $fields, 1)) {
-	return $fields;
-    }
-    return undef;
-}
+# sub getline ($$) {
+#     my($self, $io) = @_;
+#     my($fields) = [];
+#     $self->{'_ERROR_INPUT'} = undef;
+#     $self->{'_STRING'} = undef;
+#     $self->{'_FIELDS'} = $fields;
+#     if ($self->{'_STATUS'} = $self->Decode($io, $fields, 1)) {
+# 	return $fields;
+#     }
+#     return undef;
+# }
 
 
 bootstrap Text::CSV_XS $VERSION;
@@ -399,8 +398,9 @@ glob behind an IO::Wrap object. See L<IO::File(3)> and L<IO::Wrap(3)>
 for details.
 
 For performance reasons the print method doesn't create a result string.
-In particular the I<$csv->string()> method is meaningless after
-executing this method.
+In particular the I<$csv-E<gt>string()>, I<$csv-E<gt>status()>,
+I<$csv->fields()> and I<$csv-E<gt>error_input()> methods are meaningless
+after executing this method.
 
 =item string
 
@@ -432,6 +432,9 @@ combine: It reads a row from the IO object $io using $io->getline()
 and parses this row into an array ref. This array ref is returned
 by the function or undef for failure.
 
+The I<$csv-E<gt>string()>, I<$csv-E<gt>fields()> and I<$csv-E<gt>status()>
+methods are meaningless, again.
+
 =item types
 
  $csv->types(\@tref);
